package Qt::Gui::QSpinBox;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QSpinBox
# file     : QtGui/qspinbox.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Gui::QAbstractSpinBox/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QSpinBox

=head1 PUBLIC METHODS

=over

=item   QSpinBox(QWidget * parent)

=item   QSpinBox(QWidget * parent = 0)

=item  QString cleanText()

=item  int maximum()

=item  int minimum()

=item  QString prefix()

=item  void setMaximum(int max)

=item  void setMinimum(int min)

=item  void setPrefix(const QString & prefix)

=item  void setRange(int min, int max)

=item  void setSingleStep(int val)

=item  void setSuffix(const QString & suffix)

=item  void setValue(int val)

=item  int singleStep()

=item  QString suffix()

=item  int value()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
